==> patch-2.5.4.6_2.zip: app/templates/default/partials/createButton1.php <==
<?php use Helpers\Url; use Helpers\Auth;?>
<?php if(Auth::checkCloudPermission('sync')){ ?>
<?php if($data['createMiniCloud'] == 'true' || $data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
<div class="share pull-right">
    <button class="share-toggle-button universalCreate">
        <i class="createButton share-icon fa fa-plus"></i>
    </button>
    <ul class="share-items">
<?php if($data['active'] == 'sync'){ ?>
            <?php if($data['fileUpload'] == 'true') { ?>
            <li title="Folder Upload" class="share-item">
		<a href="" class="share-button" data-toggle="modal" data-target="#uploadFilesNew1" style="font-size:25px;">
		    <span class="fa-stack">
  			<i class="fa fa-folder-o fa-stack-2x" style="transform: matrix(0.6, 0, 0, 0.6, 0, 0);"></i>
  			<i class="fa fa-upload fa-stack-1x fa-inverse" style="transform: matrix(0.6, 0, 0, 0.6, 0, 1);"></i>
		    </span>
                    <!--<i class="share-icon fa fa-upload"></i>-->
                </a>
	    </li>
<?php } ?>
	<?php } ?>
</ul>
</div>
<?php } ?>
<div id="uploadFilesNew1" class="modal fade" role="dialog" data-backdrop="static" data-keyboard="false">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <h4 class="modal-title">Folder Uploader</h4>
            </div>
            <div class="modal-body">
                <div>
                    <div align="center">
<!-- yyyyyyyyyyy-->
<ul class="nav nav-tabs" style="font-size: medium;font-weight: 600;">
    <li class="nav-item" role="presentation"><a class="nav-link active" data-toggle="tab" data-target="#menu11" aria-controls="menu11" role="tab" data-toggle="tab">Choose folders to upload</a></li>
  </ul>
<div class="tab-content">
    <div id="menu11" class="tab-pane active" role="tabpanel">
      <p id="statusForFolder1" style="display:none;text-align: left;margin-left: 20px;margin-bottom: 10px;">Files Uploaded: <span id="currentCountForFolder1"></span> out of <span id="totalCountForFolder1"></span></p>
      <div id="filelist1">Your browser doesn't have Flash, Silverlight or HTML5 support.</div>
<br />
<center><span id="crawlingSpinner1" style="display:none;"><i class="fa fa-spinner fa-4x fa-pulse fa-fw"></i></span></center>
<a id="pickfiles1" href="javascript:;" >
    <div style="font-weight : 600!important;">
                                <img src="<?=Url::templatePath('default/images/Cloud-Upload-128.png');?>" />
                                <br /><br />
                                Choose Folder to Upload
                            </div></a>
      <div id="debug1">No runtime found, your browser doesn't support HTML5 drag &amp; drop upload.</div>
      <div class="bs-callout bs-callout-primary" style="padding-top: 10px; padding-bottom: 1px;">
        <p>This operation could take some time. Please be patient while the upload is in progress, and don’t close this tab. If you wish to, you can duplicate this tab and continue to perform other actions.</p>
      </div>
    </div>
    </div>
<br />
<!--yyyyyyyyyy -->
                    <span class="pull-right">
                        <button id="closeNewUpload1" type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
                    </span>
                    <br/><br/>
</div>
            </div>
        </div>
    </div>
</div>
</div>

<?php } ?>

==> patch-2.5.5.3_7_2.zip: app/templates/default/partials/createButton1.php <==
<?php use Helpers\Url; use Helpers\Auth;?>
<?php if(Auth::checkCloudPermission('sync')){ ?>
<?php if($data['createMiniCloud'] == 'true' || $data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
<div class="share pull-right">
    <button class="share-toggle-button universalCreate">
        <i class="createButton share-icon fa fa-plus"></i>
    </button>
    <ul class="share-items">
<?php if($data['active'] == 'sync'){ ?>
            <?php if($data['fileUpload'] == 'true') { ?>
            <li title="Folder Upload" class="share-item">
		<a href="" class="share-button toolTip" data-toggle="modal" data-target="#uploadFilesNew1" data-toggle="tooltip" data-placement="bottom" title="Folder Upload" style="font-size:25px;">
		    <span class="fa-stack">
  			<i class="fa fa-folder-o fa-stack-2x" style="transform: matrix(0.7, 0, 0, 0.7, 0, 0);"></i>
                        <i class="fa fa-upload fa-stack-1x fa-inverse" style="transform: matrix(0.5, 0, 0, 0.5, 0, 0);"></i>
		    </span>
                    <!--<i class="share-icon fa fa-upload"></i>-->
                </a>
	    </li>
<?php } ?>
	<?php } ?>
</ul>
</div>
<?php } ?>
<div id="uploadFilesNew1" class="modal fade" role="dialog" data-backdrop="static" data-keyboard="false">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <h4 class="modal-title">Folder Uploader</h4>
            </div>
            <div class="modal-body">
                <div>
                    <div align="center">
<!-- yyyyyyyyyyy-->
<ul class="nav nav-tabs" style="font-size: medium;font-weight: 600;">
    <li class="nav-item" role="presentation"><a class="nav-link active" data-toggle="tab" data-target="#menu11" aria-controls="menu11" role="tab" data-toggle="tab">Choose folders to upload</a></li>
  </ul>
<div class="tab-content">
    <div id="menu11" class="tab-pane active" role="tabpanel">
      <p id="statusForFolder1" style="display:none;text-align: left;margin-left: 20px;margin-bottom: 10px;">Files Uploaded: <span id="currentCountForFolder1"></span> out of <span id="totalCountForFolder1"></span></p>
      <div id="filelist1">Your browser doesn't have Flash, Silverlight or HTML5 support.</div>
<br />
<center><span id="crawlingSpinner1" style="display:none;"><i class="fa fa-spinner fa-4x fa-pulse fa-fw"></i></span></center>
<a id="pickfiles1" href="javascript:;" >
    <div style="font-weight : 600!important;">
                                <img src="<?=Url::templatePath('default/images/Cloud-Upload-128.png');?>" />
                                <br /><br />
                                Choose Folder to Upload
                            </div></a>
      <div id="debug1">No runtime found, your browser doesn't support HTML5 drag &amp; drop upload.</div>
      <div class="bs-callout bs-callout-primary" style="padding-top: 10px; padding-bottom: 1px;">
        <p>This operation could take some time. Please be patient while the upload is in progress, and don’t close this tab. If you wish to, you can duplicate this tab and continue to perform other actions.</p>
      </div>
    </div>
    </div>
<br />
<!--yyyyyyyyyy -->
                    <span class="pull-right">
                        <button id="closeNewUpload1" type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
                    </span>
                    <br/><br/>
</div>
            </div>
        </div>
    </div>
</div>
</div>

<?php } ?>
